Crate zcash_hsmbuilder

Crate zcash_hsmbuilder 

Re-exports

pub use crate::txbuilder::Builder;
pub use crate::txprover::LocalTxProver;

Modules

data
This module contains many of the data structures used in the crate and in conjunction with the HSM builder
errors
txbuilder
Structs for building transactions.
txprover
Abstractions over the proving system and parameters for ease of use.

Structs

ZcashBuilderDeprecated
Helper struct to build a transaction using an HSM, piece by piece