Re-exports
pub use crate::txbuilder::Builder;pub use crate::txprover::LocalTxProver;
Modules
- data
- This module contains many of the data structures used in the crate and in conjunction with the HSM builder
- errors
- txbuilder
- Structs for building transactions.
- txprover
- Abstractions over the proving system and parameters for ease of use.
Structs
- Zcash
Builder Deprecated - Helper struct to build a transaction using an HSM, piece by piece